class MarketCategories:
    Steam: int = 1
    VK: int = 2
    Origin: int = 3
    Warface: int = 4
    Uplay: int = 5
    SocialClub: int = 7
    Fortnite: int = 9
    Instagram: int = 10
    Battlenet: int = 11
    EpicGames: int = 12
    WoT: int = 14
    Supercell: int = 15
    WoTBlitz: int = 16
    GenshinImpact: int = 17
    Tarkov: int = 18
    VPN: int = 19
    TikTok: int = 20
    Discord: int = 22
    Cinema: int = 23
    Telegram: int = 24
    YouTube: int = 25
